@@ -24,6 +24,10 @@ from optparse import OptionParser
 from template import MakeItSoTemplate
 from template import Variable
 
+class PythonModuleTemplate(MakeItSoTemplate):
+  """single module python package"""
+  templates = ['python_module']
+
 class PythonPackageTemplate(MakeItSoTemplate):
   """
   python package template
